==> aroundme_0_6_0.tar.tgz: aroundme_0_6_0/aroundme/language/1/barnraiser_01/arrays/arr_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2004 (info@barnraiser.org)




// ROLES ------------------------------------------------------------
/*
* group roles are used as defaults when setting up a group
* once set up group roles are stored in the database
* refer to the acs_config file to see how roles are attached to sections
*/
$lang['arr_acs']['role'][0] = 			"visitor";
$lang['arr_acs']['role'][1] = 			"administrator";
$lang['arr_acs']['role'][2] = 			"contributor";
$lang['arr_acs']['role'][3] = 			"member";

$lang['arr_acs']['group_role'][0] = 	"visitor";
$lang['arr_acs']['group_role'][1] = 	"administrator";
$lang['arr_acs']['group_role'][2] = 	"contributor";
$lang['arr_acs']['group_role'][3] = 	"member";

// RESOURCES ------------------------------------------------------------
$lang['arr_acs']['resource']['node']['res'][1] = 			"Administration";
$lang['arr_acs']['resource']['node']['res'][2] = 			"Network";
$lang['arr_acs']['resource']['node']['res'][3] = 			"RSP";
$lang['arr_acs']['resource']['node']['res'][4] = 			"Shoutbox";
$lang['arr_acs']['resource']['node']['res'][5] = 			"Wiki";
$lang['arr_acs']['resource']['node']['res'][6] = 			"Discussions";
$lang['arr_acs']['resource']['node']['res'][7] = 			"Files";
$lang['arr_acs']['resource']['node']['res'][8] = 			"Schedule";
$lang['arr_acs']['resource']['node']['res'][9] = 			"Polls";
$lang['arr_acs']['resource']['node']['res'][10] = 			"Blog";
$lang['arr_acs']['resource']['node']['res'][11] = 			"Channels";
$lang['arr_acs']['resource']['node']['res'][12] = 			"Groups";
$lang['arr_acs']['resource']['node']['res'][13] = 			"Tag Management";

$lang['arr_acs']['resource']['group']['res'][201] = 		"Administration";
$lang['arr_acs']['resource']['group']['res'][202] = 		"Wiki";
$lang['arr_acs']['resource']['group']['res'][203] = 		"Discussions";
$lang['arr_acs']['resource']['group']['res'][204] = 		"Files";
$lang['arr_acs']['resource']['group']['res'][205] = 		"Schedule";
$lang['arr_acs']['resource']['group']['res'][206] = 		"Polls";
$lang['arr_acs']['resource']['group']['res'][207] = 		"Blog";
$lang['arr_acs']['resource']['group']['res'][208] = 		"Channels";
$lang['arr_acs']['resource']['group']['res'][209] = 		"RSP";

$lang['arr_acs']['resource']['node']['desc'][1] = 	"Here you can allow or deny administration section access.";
$lang['arr_acs']['resource']['node']['desc'][2] = 	"Here you can allow or deny access to the membership directory and network area and options. Members can tag other people - those tags are private.";
$lang['arr_acs']['resource']['node']['desc'][3] = 	"Here you can allow or deny access to the node RSP (really simple publishing system).";
$lang['arr_acs']['resource']['node']['desc'][4] = 	"Here you can allow or deny access to the shoutbox.";
$lang['arr_acs']['resource']['node']['desc'][5] = 	"Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource']['node']['desc'][6] = 	"Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource']['node']['desc'][7] = 	"Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource']['node']['desc'][8] = 	"Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource']['node']['desc'][9] = 	"Here you can allow or deny access to polls.";
$lang['arr_acs']['resource']['node']['desc'][10] = 	"Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource']['node']['desc'][11] = 	"Here you can allow or deny access to channels.";
$lang['arr_acs']['resource']['node']['desc'][12] = 	"Here you can allow or deny access to create groups.";
$lang['arr_acs']['resource']['node']['desc'][13] = 	"Here you can allow or deny access to tag management.";

$lang['arr_acs']['resource']['group']['desc'][201] = "Here you can allow or deny administration section access.";
$lang['arr_acs']['resource']['group']['desc'][202] = "Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource']['group']['desc'][203] = "Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource']['group']['desc'][204] = "Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource']['group']['desc'][205] = "Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource']['group']['desc'][206] = "Here you can allow or deny access to polls.";
$lang['arr_acs']['resource']['group']['desc'][207] = "Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource']['group']['desc'][208] = "Here you can allow or deny access to channels.";
$lang['arr_acs']['resource']['group']['desc'][209] = "Here you can allow or deny access to the group RSP (really simple publishing system).";


// PRIVILEGES ------------------------------------------------------------
$lang['arr_acs']['privilege'][1] = 		"Allow access to membership administration area";
$lang['arr_acs']['privilege'][2] = 		"Allow composing and sending of newsletters";
$lang['arr_acs']['privilege'][3] = 		"Allow access to permissions area (ACS)";
$lang['arr_acs']['privilege'][4] = 		"Allow group home page publishing";
$lang['arr_acs']['privilege'][5] = 		"Allow access to abuse report area";
$lang['arr_acs']['privilege'][6] = 		"Allow access to membership directory";
$lang['arr_acs']['privilege'][7] = 		"Allow access to network";
$lang['arr_acs']['privilege'][8] = 		"Allow internal invite to network";
$lang['arr_acs']['privilege'][9] = 		"Allow external invite to network";
$lang['arr_acs']['privilege'][10] = 	"Allow access";
$lang['arr_acs']['privilege'][11] = 	"Allow add/edit";
$lang['arr_acs']['privilege'][12] = 	"Allow commenting";
$lang['arr_acs']['privilege'][13] = 	"Allow locking";
$lang['arr_acs']['privilege'][14] = 	"Allow hidden";
$lang['arr_acs']['privilege'][15] = 	"Allow network publishing";
$lang['arr_acs']['privilege'][16] = 	"Allow node publishing";
$lang['arr_acs']['privilege'][17] = 	"Allow public publishing";
$lang['arr_acs']['privilege'][18] = 	"Allow tagging";
$lang['arr_acs']['privilege'][19] = 	"Allow access to view a persons profile";
$lang['arr_acs']['privilege'][20] = 	"Allow creation of a group";
$lang['arr_acs']['privilege'][21] = 	"Allow editing of a membership";
$lang['arr_acs']['privilege'][22] = 	"Allow access to group tags";
$lang['arr_acs']['privilege'][23] = 	"Allow edit";
$lang['arr_acs']['privilege'][24] = 	"Allow access to manage schedule recommended tag options";
$lang['arr_acs']['privilege'][25] = 	"Allow access to set the default page (the first page).";

?>

==> aroundme_0_6_1.tar.tgz: aroundme_0_6_1/aroundme/language/1/barnraiser_01/arrays/arr_acs.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 14th September 2004 (info@barnraiser.org)




// ROLES ------------------------------------------------------------
/*
* group roles are used as defaults when setting up a group
* once set up group roles are stored in the database
* refer to the acs_config file to see how roles are attached to sections
*/
$lang['arr_acs']['role'][1] = 			"maintainer";
$lang['arr_acs']['role'][2] = 			"contributor";
$lang['arr_acs']['role'][3] = 			"member";
$lang['arr_acs']['role'][4] = 			"visitor"; // default

$lang['arr_acs']['group_role'][1] = 	"maintainer";
$lang['arr_acs']['group_role'][2] = 	"contributor";
$lang['arr_acs']['group_role'][3] = 	"member";
$lang['arr_acs']['group_role'][4] = 	"visitor";

// RESOURCES ------------------------------------------------------------
$lang['arr_acs']['resource']['node']['res'][1] = 			"Administration";
$lang['arr_acs']['resource']['node']['res'][2] = 			"Network";
$lang['arr_acs']['resource']['node']['res'][3] = 			"RSP";
$lang['arr_acs']['resource']['node']['res'][4] = 			"Shoutbox";
$lang['arr_acs']['resource']['node']['res'][5] = 			"Wiki";
$lang['arr_acs']['resource']['node']['res'][6] = 			"Discussions";
$lang['arr_acs']['resource']['node']['res'][7] = 			"Files";
$lang['arr_acs']['resource']['node']['res'][8] = 			"Schedule";
$lang['arr_acs']['resource']['node']['res'][9] = 			"Polls";
$lang['arr_acs']['resource']['node']['res'][10] = 			"Blog";
$lang['arr_acs']['resource']['node']['res'][11] = 			"Channels";
$lang['arr_acs']['resource']['node']['res'][12] = 			"Groups";
$lang['arr_acs']['resource']['node']['res'][13] = 			"Tag Management";

$lang['arr_acs']['resource']['group']['res'][201] = 		"Administration";
$lang['arr_acs']['resource']['group']['res'][202] = 		"Wiki";
$lang['arr_acs']['resource']['group']['res'][203] = 		"Discussions";
$lang['arr_acs']['resource']['group']['res'][204] = 		"Files";
$lang['arr_acs']['resource']['group']['res'][205] = 		"Schedule";
$lang['arr_acs']['resource']['group']['res'][206] = 		"Polls";
$lang['arr_acs']['resource']['group']['res'][207] = 		"Blog";
$lang['arr_acs']['resource']['group']['res'][208] = 		"Channels";
$lang['arr_acs']['resource']['group']['res'][209] = 		"RSP";

$lang['arr_acs']['resource']['node']['desc'][1] = 	"Here you can allow or deny administration section access.";
$lang['arr_acs']['resource']['node']['desc'][2] = 	"Here you can allow or deny access to the membership directory and network area and options. Members can tag other people - those tags are private.";
$lang['arr_acs']['resource']['node']['desc'][3] = 	"Here you can allow or deny access to the node RSP (really simple publishing system).";
$lang['arr_acs']['resource']['node']['desc'][4] = 	"Here you can allow or deny access to the shoutbox.";
$lang['arr_acs']['resource']['node']['desc'][5] = 	"Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource']['node']['desc'][6] = 	"Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource']['node']['desc'][7] = 	"Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource']['node']['desc'][8] = 	"Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource']['node']['desc'][9] = 	"Here you can allow or deny access to polls.";
$lang['arr_acs']['resource']['node']['desc'][10] = 	"Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource']['node']['desc'][11] = 	"Here you can allow or deny access to channels.";
$lang['arr_acs']['resource']['node']['desc'][12] = 	"Here you can allow or deny access to create groups.";
$lang['arr_acs']['resource']['node']['desc'][13] = 	"Here you can allow or deny access to tag management.";

$lang['arr_acs']['resource']['group']['desc'][201] = "Here you can allow or deny administration section access.";
$lang['arr_acs']['resource']['group']['desc'][202] = "Here you can allow or deny access to the wiki. There is one wiki for the node. If you give someone the rights to edit they can edit all pages.";
$lang['arr_acs']['resource']['group']['desc'][203] = "Here you can allow or deny access to the discussions area. They can add or edit Topics. When you add a topic you assign permissions to the discussion then.";
$lang['arr_acs']['resource']['group']['desc'][204] = "Here you can allow or deny access to the files. Files are not published. To publish them they are included in a blog or wiki (for example) and then they adopt the publishing rights of that parent item.";
$lang['arr_acs']['resource']['group']['desc'][205] = "Here you can allow or deny access to schedule items.";
$lang['arr_acs']['resource']['group']['desc'][206] = "Here you can allow or deny access to polls.";
$lang['arr_acs']['resource']['group']['desc'][207] = "Here you can allow or deny access to blogs.";
$lang['arr_acs']['resource']['group']['desc'][208] = "Here you can allow or deny access to channels.";
$lang['arr_acs']['resource']['group']['desc'][209] = "Here you can allow or deny access to the group RSP (really simple publishing system).";


// PRIVILEGES ------------------------------------------------------------
$lang['arr_acs']['privilege'][1] = 		"Allow access to membership administration area";
$lang['arr_acs']['privilege'][2] = 		"Allow composing and sending of newsletters";
$lang['arr_acs']['privilege'][3] = 		"Allow access to permissions area (ACS)";
$lang['arr_acs']['privilege'][4] = 		"Allow group home page publishing";
$lang['arr_acs']['privilege'][5] = 		"Allow access to abuse report area";
$lang['arr_acs']['privilege'][6] = 		"Allow access to membership directory";
$lang['arr_acs']['privilege'][7] = 		"Allow access to network";
$lang['arr_acs']['privilege'][8] = 		"Allow internal invite to network";
$lang['arr_acs']['privilege'][9] = 		"Allow external invite to network";
$lang['arr_acs']['privilege'][10] = 	"Allow access";
$lang['arr_acs']['privilege'][11] = 	"Allow add/edit";
$lang['arr_acs']['privilege'][12] = 	"Allow commenting";
$lang['arr_acs']['privilege'][13] = 	"Allow locking";
$lang['arr_acs']['privilege'][14] = 	"Allow hidden";
$lang['arr_acs']['privilege'][15] = 	"Allow network publishing";
$lang['arr_acs']['privilege'][16] = 	"Allow node publishing";
$lang['arr_acs']['privilege'][17] = 	"Allow public publishing";
$lang['arr_acs']['privilege'][18] = 	"Allow tagging";
$lang['arr_acs']['privilege'][19] = 	"Allow access to view a persons profile";
$lang['arr_acs']['privilege'][20] = 	"Allow creation of a group";
$lang['arr_acs']['privilege'][21] = 	"Allow editing of a membership";
$lang['arr_acs']['privilege'][22] = 	"Allow access to group tags";
$lang['arr_acs']['privilege'][23] = 	"Allow edit";
$lang['arr_acs']['privilege'][24] = 	"Allow access to manage schedule recommended tag options";
$lang['arr_acs']['privilege'][25] = 	"Allow access to set the default page (the first page).";

?>
